```
Usage: vcd gateway services firewall delete-source [OPTIONS] <name> <id>
                                                   <source_value>

Options:
  -h, --help  Show this message and exit.

```
